@@ -21,21 +21,24 @@ class api:
         response = self.handle_request(request)
         return response(environ, start_response)
 
-    def handle_request(self, request, mimetype="text/html"):
+    def handle_request(self, request):
         #user_agent = request.environ.get('HTTP_USER_AGENT')
-        response = Response(content_type=mimetype)
+        response = Response()
         response.status_code = 200
         response.text = "Blank"
         with open("access-log.txt", "wb") as f:
-            f.write(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200').encode())
+            f.writeline(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200').encode())
         
         handler = self.find_handler(request)
 
         if handler is not None:
             handler(response)
         else:
-            self.err404(response)
-
+            try:
+                return Response(body=open(request.path, "rb"))
+            except e:
+                print(e)
+                self.err404(response)
         return response
 
     def catchURL(self, path):
@@ -67,7 +70,7 @@ class api:
             raise Exception("Invalid Error Code")
 
     def run(self, app):
-        print("run")
+        print("running at 127.0.0.1 at port 8000")
         host = "127.0.0.1"
         port = 6000
 
